@@ -83,8 +83,11 @@ __all__ = [
     'vtkInteractionWidgets',
     'vtkViewsCore',
     'vtkViewsContext2D',
-    'vtkTestingRendering',
     'vtkRenderingUI',
+    'vtkImagingColor',
+    'vtkTestingRendering',
+    'vtkFiltersCellGrid',
+    'vtkIOCellGrid',
     'vtkIOLegacy',
     'vtkDomainsChemistry',
     'vtkRenderingHyperTreeGrid',
@@ -102,7 +105,6 @@ __all__ = [
     'vtkRenderingMatplotlib',
     'vtkRenderingLabel',
     'vtkRenderingContextOpenGL2',
-    'vtkFiltersCellGrid',
     'vtkRenderingCellGrid',
     'vtkParallelMPI4Py',
     'vtkImagingFourier',
@@ -149,21 +151,22 @@ __all__ = [
     'vtkRenderingGL2PSOpenGL2',
     'vtkIOExportGL2PS',
     'vtkIOEnSight',
+    'vtkIOHDF',
+    'vtkIOERF',
     'vtkIOCityGML',
     'vtkIOChemistry',
-    'vtkIOCellGrid',
     'vtkIOCONVERGECFD',
-    'vtkIOHDF',
     'vtkIOCGNSReader',
     'vtkIOAsynchronous',
     'vtkIOAMR',
     'vtkIOADIOS2',
     'vtkIOGDAL',
-    'vtkImagingColor',
+    'vtkGeovisCore',
     'vtkRenderingAnnotation',
     'vtkInteractionStyle',
     'vtkImagingHybrid',
     'vtkFiltersTensor',
+    'vtkFiltersTemporal',
     'vtkFiltersPython',
     'vtkFiltersProgrammable',
     'vtkFiltersModeling',
@@ -193,6 +196,7 @@ __all__ = [
     'vtkDomainsChemistryOpenGL2',
     'vtkChartsCore',
     'vtkAcceleratorsVTKmFilters',
+    'vtkFiltersReduction',
     'all',
     'gtk',
     'numpy_interface',
@@ -205,4 +209,4 @@ __all__ = [
 
 #------------------------------------------------------------------------------
 # get the version
-__version__ = "9.3.20231030"
+__version__ = "9.3.20240617"
