@@ -29,8 +29,11 @@ from .vtkFiltersSources import *
 from .vtkInteractionWidgets import *
 from .vtkViewsCore import *
 from .vtkViewsContext2D import *
-from .vtkTestingRendering import *
 from .vtkRenderingUI import *
+from .vtkImagingColor import *
+from .vtkTestingRendering import *
+from .vtkFiltersCellGrid import *
+from .vtkIOCellGrid import *
 from .vtkIOLegacy import *
 from .vtkDomainsChemistry import *
 from .vtkRenderingHyperTreeGrid import *
@@ -48,7 +51,6 @@ from .vtkRenderingParallel import *
 from .vtkRenderingMatplotlib import *
 from .vtkRenderingLabel import *
 from .vtkRenderingContextOpenGL2 import *
-from .vtkFiltersCellGrid import *
 from .vtkRenderingCellGrid import *
 from .vtkParallelMPI4Py import *
 from .vtkImagingFourier import *
@@ -95,21 +97,22 @@ from .vtkInfovisCore import *
 from .vtkRenderingGL2PSOpenGL2 import *
 from .vtkIOExportGL2PS import *
 from .vtkIOEnSight import *
+from .vtkIOHDF import *
+from .vtkIOERF import *
 from .vtkIOCityGML import *
 from .vtkIOChemistry import *
-from .vtkIOCellGrid import *
 from .vtkIOCONVERGECFD import *
-from .vtkIOHDF import *
 from .vtkIOCGNSReader import *
 from .vtkIOAsynchronous import *
 from .vtkIOAMR import *
 from .vtkIOADIOS2 import *
 from .vtkIOGDAL import *
-from .vtkImagingColor import *
+from .vtkGeovisCore import *
 from .vtkRenderingAnnotation import *
 from .vtkInteractionStyle import *
 from .vtkImagingHybrid import *
 from .vtkFiltersTensor import *
+from .vtkFiltersTemporal import *
 from .vtkFiltersPython import *
 from .vtkFiltersProgrammable import *
 from .vtkFiltersModeling import *
@@ -139,6 +142,7 @@ from .vtkFiltersParallelMPI import *
 from .vtkDomainsChemistryOpenGL2 import *
 from .vtkChartsCore import *
 from .vtkAcceleratorsVTKmFilters import *
+from .vtkFiltersReduction import *
 
 
 # useful macro for getting type names
